==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'Weergave in vakjes',
	'affichage_documents_en_grand' => 'Grote weergave',
	'affichage_documents_en_liste_compacte' => 'Compacte lijstweergave',
	'aucun_audio' => 'Geen geluidsbestand',
	'aucun_document' => 'Geen document',
	'aucun_file' => 'Geen bestand',
	'aucun_image' => 'Geen afbeelding',
	'aucun_video' => 'Geen video',
	'aucune_utilisation' => 'Dit document wordt nergens gebruikt',
	'aucune_vignette' => 'Geen verkleining',

	// B
	'bouton_ajouter_document' => 'Een document toevoegen',
	'bouton_ajouter_image' => 'Een afbeelding toevoegen',
	'bouton_ajouter_image_document' => 'Een afbeelding of een document toevoegen',
	'bouton_attacher_document' => 'Koppelen',
	'bouton_copier_local' => 'Kopiëren in het site',
	'bouton_download_depuis' => 'vanaf:',
	'bouton_download_local' => 'mijn computer',
	'bouton_download_par_ftp' => 'de server',
	'bouton_download_par_mediatheque' => 'de mediatheek',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Ontkoppelen',
	'bouton_enlever_supprimer_document' => 'Verwijderen',
	'bouton_enlever_supprimer_document_confirmation' => 'Weet je zeker dat je het document wilt verwijderen?',
	'bouton_modifier_document' => 'Aanpassen',
	'bouton_parcourir' => 'Doorlopen...',
	'bouton_refresh_document' => 'Document verversen',
	'bouton_remplacer_document' => 'Dit document vervangen',
	'bouton_remplacer_image' => 'Deze afbeelding vervangen',
	'bouton_remplacer_image_document' => 'Een afbeelding of een document vervangen',
	'bouton_supprimer' => 'Verwijderen',
	'bouton_supprimer_tous_orphelins' => 'Alle weesbestanden verwijderen',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Weet je zeker dat je @nb@ weesbestanden wilt verwijderen?',
	'bouton_upload' => 'Uploaden',

	// D
	'des_audios' => '@nb@ geluidsbestanden',
	'des_documents' => '@nb@ documenten',
	'des_files' => '@nb@ bestanden',
	'des_images' => '@nb@ afbeeldingen',
	'des_utilisations' => '@nb@ toepassingen',
	'des_videos' => '@nb@ videos',
	'descriptif' => 'Beschrijving',
	'details_document' => 'Details',
	'details_document_afficher_masquer' => 'Toon/verberg de details van het document',
	'document_attache_succes' => 'Het document werd bijgevoegd',
	'document_copie_locale_succes' => 'Het bestand werd op de site gekopieerd',
	'document_installe_succes' => 'Het bestand werd opgeslagen',
	'document_vu' => 'In de tekst geplaatst',
	'documents' => 'Mediatheek',
	'documents_brises' => 'Verbroken',
	'documents_distants' => 'Remote',
	'documents_locaux' => 'Lokaal',
	'documents_non_publies' => 'Niet gepubliceerd',
	'documents_orphelins' => 'Ongebruikt',
	'documents_publies' => 'Gepubliceerd',
	'documents_tous' => 'Alles',
	'double_clic_inserer_doc' => 'Dubbelklik om deze snelkoppeling in de tekst te voegen.',

	// E
	'entree_dimensions' => 'Afmetingen:',
	'entree_titre_document' => 'Documenttitel:',
	'entree_titre_image' => 'Afbeeldingstitel:',
	'erreur_aucun_document' => 'Dit document bestaat niet in de mediatheek ',
	'erreur_aucun_fichier' => 'Er werd geen bestand gevonden',
	'erreur_autorisation' => 'Autorisatiefout.',
	'erreur_chemin_distant' => 'Remote bestand @nom@ werd niet gevonden',
	'erreur_chemin_ftp' => 'Het gekozen bestand werd niet op de server gevonden',
	'erreur_copie_fichier' => 'Onmogelijk het bestand @nom@ te kopiëren ',
	'erreur_deplacement_impossible' => 'Verplaatsen niet mogelijk.',
	'erreur_dossier_tmp_manquant' => 'Er ontbreekt een tijdelijke map om de bestanden te uploaden',
	'erreur_ecriture_fichier' => 'Fout tijdens het schrijven van het bestand op de server',
	'erreur_format_fichier_image' => 'Het @nom@ formaat is ongeldig voor een afbeelding',
	'erreur_indiquez_un_fichier' => 'Geef een bestand aan!',
	'erreur_insertion_document_base' => 'Onmogelijk het document @fichier@ in de database op te slaan',
	'erreur_objet_absent' => 'Onvolledige informatie ontvangen.',
	'erreur_suppression_vignette' => 'Fout tijdens het uitwissen van de verkleining',
	'erreur_upload_type_interdit' => 'Het uploaden van bestanden met type @nom@ is niet toegelaten',
	'erreur_upload_vignette' => 'Fout tijdens het laden van de verkleining @nom@',
	'erreurs' => '@nb@ fouten',
	'erreurs_voir' => 'De @nb@ fouten kijken',

	// F
	'fichier_distant' => 'Remote bestand',
	'fichier_manquant' => 'Ontbrekend bestand',
	'fichier_modifie' => 'Het bestand werd veranderd. Klik op opslaan.',
	'format_date_incorrect' => 'Datum of tijdstip is ongeldig',

	// I
	'icone_creer_document' => 'Een document bijvoegen',
	'id' => 'ID',
	'image_tourner_180' => '180° draaien',
	'image_tourner_droite' => '90° rechtsom draaien',
	'image_tourner_gauche' => '90° linksom draaien',
	'info_dimensions_image' => 'Afmetingen',
	'info_doc_max_poids' => 'De documenten moeten verplicht minder dan @maxi@ groot zijn (dit bestand is @actuel@).',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Dit document is niet beschikbaar',
	'info_documents' => 'documenten',
	'info_duree' => 'Duur',
	'info_gauche_numero_document' => 'DOCUMENT NUMMER',
	'info_hauteur' => 'Hoogte',
	'info_heure' => 'Tijdstip',
	'info_illustrations' => 'Illustraties',
	'info_image_max_poids' => 'De afbeeldingen moeten verplicht minder dan @maxi@ groot zijn (huidige bestand is @actuel@).',
	'info_image_max_taille' => 'De afbeeldingen moeten verplicht minder dan @maxi@ groot zijn (huidige bestand is @actuel@).',
	'info_inclusion_directe' => 'Directe insluiting:',
	'info_inclusion_vignette' => 'Insluiten van de miniatuurafbeelding:',
	'info_installer_tous_documents' => 'Alle documenten installeren',
	'info_largeur' => 'Breedte',
	'info_logo_max_taille' => 'Logo’s mogen maximaal @maxi@ zijn (dit bestand is @actuel@).',
	'info_mode' => 'Modus',
	'info_modifier_document' => 'Document veranderen',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Naar een document op internet verwijzen:',
	'info_resolution_image' => 'Resolutie',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Zonder verkleining',
	'info_statut_document' => 'Deze document is:',
	'info_taille' => 'Gewicht',
	'info_telecharger' => 'Opladen vanaf je computer:',
	'info_utilisation' => 'Toepassing(en)',
	'infos' => 'Technische info',
	'item_autoriser_selectionner_date_en_ligne' => 'Het mogelijk maken om de datum van elk document te wijzigen',
	'item_non_autoriser_selectionner_date_en_ligne' => 'De datum van de documenten is die van hun toevoeging aan de site',

	// L
	'label_activer_document_objets' => 'Documenten activeren voor volgende inhoud:',
	'label_apercu' => 'Overzicht',
	'label_caracteristiques' => 'Kenmerken',
	'label_credits' => 'Credits',
	'label_fichier' => 'Bestand',
	'label_fichier_vignette' => 'Verkleining',
	'label_paginer_par' => 'Pagineren per:',
	'label_parents' => 'Dit document is gekoppeld aan',
	'label_refdoc_joindre' => 'Document nummer',
	'lien_tout_desordonner' => 'De volgorde opnieuw instellen',
	'lien_tout_desordonner_verif' => 'De gegeven volgorde voor deze lijst zal opnieuw worden ingesteld. Weet je het zeker?',
	'lien_tout_enlever' => 'Alles verwijderen',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Geluidsbestand',
	'media_file' => 'Andere',
	'media_image' => 'Afbeeldingen',
	'media_video' => 'Videosequenties',
	'miniature_automatique_active' => 'SPIP zal automatisch een verkleining van de afbeelding aanmaken',

	// N
	'nb_documents_attache_succes' => '@nb@ documenten werden bijgevoegd',
	'nb_documents_installe_succes' => '@nb@ bestanden werden met succes opgeslagen ',

	// O
	'objet_document' => 'Document',
	'objet_documents' => 'Documenten',
	'ordonner_ce_document' => 'Dit document ordenen',

	// P
	'par_date' => 'Datum',
	'par_hauteur' => 'Hoogte',
	'par_id' => 'ID',
	'par_largeur' => 'Breedte',
	'par_taille' => 'Grootte',
	'par_titre' => 'Titel',

	// T
	'texte_documents_joints' => 'Je kan het toevoegen van documenten (teksten, afbeeldingen, multimedia, ...) bij artikelen, rubrieken en andere toelaten. De bijgevoegde bestanden kunnen vervolgens in de 
tekst opgenomen worden of afzonderlijk worden getoond.',
	'texte_documents_joints_2' => 'Deze instelling verhindert de directe opname van afbeeldingen of andere inhoud in de tekst van een object (artikel, ...).',
	'titre_documents_joints' => 'Bijlagen',
	'titre_page_documents_edit' => 'Document aanpassen: @titre@',
	'tous_les_medias' => 'Alle medias',
	'tout_dossier_upload' => 'Alles in de map @upload@',
	'tout_voir' => 'Alles bekijken',

	// U
	'un_audio' => '1 geluidsbestand',
	'un_document' => '1 document',
	'un_file' => '1 bestand',
	'un_image' => '1 afbeelding',
	'un_video' => '1 videosequentie',
	'une_utilisation' => '1 toepassing',
	'upload_fichier_zip' => 'ZIP bestand',
	'upload_fichier_zip_texte' => 'Het bestand dat je wil installeren is een ZIP bestand.',
	'upload_fichier_zip_texte2' => 'Dit bestand kan zijn:',
	'upload_info_mode_document' => 'In de portfolio plaatsen',
	'upload_info_mode_image' => 'Uit de portfolio halen ',
	'upload_limit' => 'Dit bestand is te groot voor de server; de maximale bestandsgrootte voor <i>upload</i> is @max@.',
	'upload_zip_conserver' => 'Het archief bewaren na het unzippen',
	'upload_zip_decompacter' => 'uitgepakt en elk bestand geïnstalleerd op de site. De bestanden die op de site komen, zijn:',
	'upload_zip_mode_document' => 'Alle documenten in de portfolio plaatsen',
	'upload_zip_telquel' => 'geïnstalleerd als gezipt (gecomprimeerd) bestand ;',
	'upload_zip_titrer' => 'Volgens de bestandsnaam betitelen',

	// V
	'verifier_documents_brises' => 'Ontbrekende bestanden checken',
	'verifier_documents_inutilises' => 'Links naar documenten checken',
	'vignette_supprimee' => 'Verkleining wordt verwijderd'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'Weergave in vakjes',
	'affichage_documents_en_grand' => 'Grote weergave',
	'affichage_documents_en_liste_compacte' => 'Compacte lijstweergave',
	'aucun_audio' => 'Geen geluidsbestand',
	'aucun_document' => 'Geen document',
	'aucun_file' => 'Geen bestand',
	'aucun_image' => 'Geen afbeelding',
	'aucun_video' => 'Geen video',
	'aucune_utilisation' => 'Dit document wordt nergens gebruikt',
	'aucune_vignette' => 'Geen verkleining',

	// B
	'bouton_ajouter_document' => 'Een document toevoegen',
	'bouton_ajouter_image' => 'Een afbeelding toevoegen',
	'bouton_ajouter_image_document' => 'Een afbeelding of een document toevoegen',
	'bouton_attacher_document' => 'Koppelen',
	'bouton_copier_local' => 'Kopiëren in het site',
	'bouton_download_depuis' => 'vanaf:',
	'bouton_download_local' => 'mijn computer',
	'bouton_download_par_ftp' => 'de server',
	'bouton_download_par_mediatheque' => 'de mediatheek',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Ontkoppelen',
	'bouton_enlever_supprimer_document' => 'Verwijderen',
	'bouton_enlever_supprimer_document_confirmation' => 'Weet je zeker dat je het document wilt verwijderen?',
	'bouton_modifier_document' => 'Aanpassen',
	'bouton_parcourir' => 'Doorlopen...',
	'bouton_refresh_document' => 'Document verversen',
	'bouton_remplacer_document' => 'Dit document vervangen',
	'bouton_remplacer_image' => 'Deze afbeelding vervangen',
	'bouton_remplacer_image_document' => 'Een afbeelding of een document vervangen',
	'bouton_supprimer' => 'Verwijderen',
	'bouton_supprimer_tous_orphelins' => 'Alle weesbestanden verwijderen', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Weet je zeker dat je @nb@ weesbestanden wilt verwijderen?', # MODIF
	'bouton_upload' => 'Uploaden',

	// D
	'des_audios' => '@nb@ geluidsbestanden',
	'des_documents' => '@nb@ documenten',
	'des_files' => '@nb@ bestanden',
	'des_images' => '@nb@ afbeeldingen',
	'des_utilisations' => '@nb@ toepassingen',
	'des_videos' => '@nb@ videos',
	'descriptif' => 'Beschrijving',
	'details_document' => 'Details',
	'details_document_afficher_masquer' => 'Toon/verberg de details van het document',
	'document_attache_succes' => 'Het document werd bijgevoegd',
	'document_copie_locale_succes' => 'Het bestand werd op de site gekopieerd',
	'document_installe_succes' => 'Het bestand werd opgeslagen',
	'document_vu' => 'In de tekst geplaatst',
	'documents' => 'Mediatheek',
	'documents_brises' => 'Verbroken',
	'documents_distants' => 'Remote',
	'documents_locaux' => 'Lokaal',
	'documents_non_publies' => 'Niet gepubliceerd',
	'documents_orphelins' => 'Ongebruikt',
	'documents_publies' => 'Gepubliceerd',
	'documents_tous' => 'Alles',
	'double_clic_inserer_doc' => 'Dubbelklik om deze snelkoppeling in de tekst te voegen.',

	// E
	'entree_dimensions' => 'Afmetingen:',
	'entree_titre_document' => 'Documenttitel:',
	'entree_titre_image' => 'Afbeeldingstitel:',
	'erreur_aucun_document' => 'Dit document bestaat niet in de mediatheek ',
	'erreur_aucun_fichier' => 'Er werd geen bestand gevonden',
	'erreur_autorisation' => 'Autorisatiefout.',
	'erreur_chemin_distant' => 'Remote bestand @nom@ werd niet gevonden',
	'erreur_chemin_ftp' => 'Het gekozen bestand werd niet op de server gevonden',
	'erreur_copie_fichier' => 'Onmogelijk het bestand @nom@ te kopiëren ',
	'erreur_deplacement_impossible' => 'Verplaatsen niet mogelijk.',
	'erreur_dossier_tmp_manquant' => 'Er ontbreekt een tijdelijke map om de bestanden te uploaden',
	'erreur_ecriture_fichier' => 'Fout tijdens het schrijven van het bestand op de server',
	'erreur_format_fichier_image' => 'Het @nom@ formaat is ongeldig voor een afbeelding',
	'erreur_indiquez_un_fichier' => 'Geef een bestand aan!',
	'erreur_insertion_document_base' => 'Onmogelijk het document @fichier@ in de database op te slaan',
	'erreur_objet_absent' => 'Onvolledige informatie ontvangen.',
	'erreur_suppression_vignette' => 'Fout tijdens het uitwissen van de verkleining',
	'erreur_upload_type_interdit' => 'Het uploaden van bestanden met type @nom@ is niet toegelaten',
	'erreur_upload_vignette' => 'Fout tijdens het laden van de verkleining @nom@',
	'erreurs' => '@nb@ fouten',
	'erreurs_voir' => 'De @nb@ fouten kijken',

	// F
	'fichier_distant' => 'Remote bestand',
	'fichier_manquant' => 'Ontbrekend bestand',
	'fichier_modifie' => 'Het bestand werd veranderd. Klik op opslaan.',
	'format_date_incorrect' => 'Datum of tijdstip is ongeldig',

	// I
	'icone_creer_document' => 'Een document bijvoegen',
	'id' => 'ID',
	'image_tourner_180' => '180° draaien',
	'image_tourner_droite' => '90° rechtsom draaien',
	'image_tourner_gauche' => '90° linksom draaien',
	'info_dimensions_image' => 'Afmetingen',
	'info_doc_max_poids' => 'De documenten moeten verplicht minder dan @maxi@ groot zijn (dit bestand is @actuel@).',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Dit document is niet beschikbaar',
	'info_documents' => 'documenten',
	'info_duree' => 'Duur',
	'info_gauche_numero_document' => 'DOCUMENT NUMMER',
	'info_hauteur' => 'Hoogte',
	'info_heure' => 'Tijdstip',
	'info_illustrations' => 'Illustraties',
	'info_image_max_poids' => 'De afbeeldingen moeten verplicht minder dan @maxi@ groot zijn (huidige bestand is @actuel@).',
	'info_image_max_taille' => 'De afbeeldingen moeten verplicht minder dan @maxi@ groot zijn (huidige bestand is @actuel@).',
	'info_inclusion_directe' => 'Directe insluiting:',
	'info_inclusion_vignette' => 'Insluiten van de miniatuurafbeelding:',
	'info_installer_tous_documents' => 'Alle documenten installeren',
	'info_largeur' => 'Breedte',
	'info_logo_max_taille' => 'Logo’s mogen maximaal @maxi@ zijn (dit bestand is @actuel@).',
	'info_mode' => 'Modus',
	'info_modifier_document' => 'Document veranderen',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Naar een document op internet verwijzen:',
	'info_resolution_image' => 'Resolutie',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Zonder verkleining',
	'info_statut_document' => 'Deze document is:',
	'info_taille' => 'Gewicht',
	'info_telecharger' => 'Opladen vanaf je computer:',
	'info_utilisation' => 'Toepassing(en)',
	'infos' => 'Technische info',
	'item_autoriser_selectionner_date_en_ligne' => 'Het mogelijk maken om de datum van elk document te wijzigen',
	'item_non_autoriser_selectionner_date_en_ligne' => 'De datum van de documenten is die van hun toevoeging aan de site',

	// L
	'label_activer_document_objets' => 'Documenten activeren voor volgende inhoud:',
	'label_apercu' => 'Overzicht',
	'label_caracteristiques' => 'Kenmerken',
	'label_credits' => 'Credits',
	'label_fichier' => 'Bestand',
	'label_fichier_vignette' => 'Verkleining',
	'label_paginer_par' => 'Pagineren per:',
	'label_parents' => 'Dit document is gekoppeld aan',
	'label_refdoc_joindre' => 'Document nummer',
	'lien_tout_desordonner' => 'De volgorde opnieuw instellen',
	'lien_tout_desordonner_verif' => 'De gegeven volgorde voor deze lijst zal opnieuw worden ingesteld. Weet je het zeker?',
	'lien_tout_enlever' => 'Alles verwijderen', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Geluidsbestand',
	'media_file' => 'Andere',
	'media_image' => 'Afbeeldingen',
	'media_video' => 'Videosequenties',
	'miniature_automatique_active' => 'SPIP zal automatisch een verkleining van de afbeelding aanmaken',

	// N
	'nb_documents_attache_succes' => '@nb@ documenten werden bijgevoegd',
	'nb_documents_installe_succes' => '@nb@ bestanden werden met succes opgeslagen ',

	// O
	'objet_document' => 'Document',
	'objet_documents' => 'Documenten',
	'ordonner_ce_document' => 'Dit document ordenen',

	// P
	'par_date' => 'Datum',
	'par_hauteur' => 'Hoogte',
	'par_id' => 'ID',
	'par_largeur' => 'Breedte',
	'par_taille' => 'Grootte',
	'par_titre' => 'Titel',

	// T
	'texte_documents_joints' => 'Je kan het toevoegen van documenten (teksten, afbeeldingen, multimedia, ...) bij artikelen, rubrieken en andere toelaten. De bijgevoegde bestanden kunnen vervolgens in de 
tekst opgenomen worden of afzonderlijk worden getoond.',
	'texte_documents_joints_2' => 'Deze instelling verhindert de directe opname van afbeeldingen of andere inhoud in de tekst van een object (artikel, ...).',
	'titre_documents_joints' => 'Bijlagen',
	'titre_page_documents_edit' => 'Document aanpassen: @titre@',
	'tous_les_medias' => 'Alle medias',
	'tout_dossier_upload' => 'Alles in de map @upload@',
	'tout_voir' => 'Alles bekijken',

	// U
	'un_audio' => '1 geluidsbestand',
	'un_document' => '1 document',
	'un_file' => '1 bestand',
	'un_image' => '1 afbeelding',
	'un_video' => '1 videosequentie',
	'une_utilisation' => '1 toepassing',
	'upload_fichier_zip' => 'ZIP bestand',
	'upload_fichier_zip_texte' => 'Het bestand dat je wil installeren is een ZIP bestand.',
	'upload_fichier_zip_texte2' => 'Dit bestand kan zijn:',
	'upload_info_mode_document' => 'In de portfolio plaatsen',
	'upload_info_mode_image' => 'Uit de portfolio halen ',
	'upload_limit' => 'Dit bestand is te groot voor de server; de maximale bestandsgrootte voor <i>upload</i> is @max@.',
	'upload_zip_conserver' => 'Het archief bewaren na het unzippen',
	'upload_zip_decompacter' => 'uitgepakt en elk bestand geïnstalleerd op de site. De bestanden die op de site komen, zijn:',
	'upload_zip_mode_document' => 'Alle documenten in de portfolio plaatsen',
	'upload_zip_telquel' => 'geïnstalleerd als gezipt (gecomprimeerd) bestand ;',
	'upload_zip_titrer' => 'Volgens de bestandsnaam betitelen',

	// V
	'verifier_documents_brises' => 'Ontbrekende bestanden checken',
	'verifier_documents_inutilises' => 'Links naar documenten checken',
	'vignette_supprimee' => 'Verkleining wordt verwijderd'
);
